@@ -6,6 +6,7 @@ Sjors H.W. Scheres, Takanori Nakane, Colin M. Palmer, Donovan Webb"""
 import argparse
 import json
 import os
+import shutil
 import time
 from glob import glob
 import subprocess
@@ -16,11 +17,11 @@ from emtable import Table  # requires pip install emtable
 RELION_JOB_FAILURE_FILENAME = "RELION_JOB_EXIT_FAILURE"
 RELION_JOB_SUCCESS_FILENAME = "RELION_JOB_EXIT_SUCCESS"
 DONE_MICS = "done_mics.txt"
-CONDA_ENV = ". ~/rc/conda.rc && conda activate cryolo-1.7.5"
+CONDA_ENV = ". /home/gsharov/rc/conda.rc && conda activate cryolo-1.7.5"
 CRYOLO_PREDICT = "cryolo_predict.py"
 CRYOLO_GEN_MODEL = "/home/gsharov/soft/cryolo/gmodel_phosnet_202005_N63_c17.h5"
 CRYOLO_JANNI_MODEL = "/home/gsharov/soft/cryolo/gmodel_janni_20190703.h5"
-DEBUG = 1
+DEBUG = 0
 
 
 def run_job(project_dir, args):
@@ -29,6 +30,7 @@ def run_job(project_dir, args):
     job_dir = args.out_dir
     thresh = args.threshold
     box_size = args.box_size
+    distance = 0
     model = args.model
     gpus = args.gpu
     threads = args.threads
@@ -53,6 +55,7 @@ def run_job(project_dir, args):
 
     if box_size:  # is not 0
         json_dict["model"]["anchors"] = [int(box_size), int(box_size)]
+        distance = int(box_size / 2)  # use half the box_size
 
     if DEBUG:
         print("Using following config.json: ", json_dict)
@@ -73,34 +76,30 @@ def run_job(project_dir, args):
         print("Current done_mics: ", done_mics)
 
     mic_fns = mictable.getColumnValues("rlnMicrographName")
+    mic_ext = os.path.splitext(mic_fns[0])[1]
     input_job = "/".join(mic_fns[0].split("/")[:2])
     keys = ["/".join(i.split("/")[2:]) for i in mic_fns]  # remove JobType/jobXXX
     values = [os.path.splitext(i)[0] + "_cryolo.star" for i in keys]  # _cryolo.star
-    mic_dict = {k: v for k, v in zip(keys, values)}
+    mic_dict = {k: v for k, v in zip(keys, values) if k not in done_mics}
 
     for mic in mic_dict:
         if DEBUG:
             print("Processing mic: ", mic)
         mic_dir = os.path.dirname(mic)
+        # create folder for micrograph links for cryolo job
         if not os.path.isdir(mic_dir):
             os.makedirs(mic_dir)
         if mic_dir not in mic_dirs:
             mic_dirs.append(mic_dir)
-            print("Added folder %s to the mic_dirs" % mic_dir)
-        if mic not in done_mics:
-            inputfn = getPath(input_job, mic)
-            outfn = getPath(job_dir, mic)
+            if DEBUG:
+                print("Added folder %s to the mic_dirs" % mic_dir)
+        inputfn = getPath(input_job, mic)
+        outfn = getPath(job_dir, mic)
+        os.symlink(inputfn, outfn)
+        if DEBUG:
+            print("Link %s --> %s" % (inputfn, outfn))
 
-            # if mic had no coords picked, symlink still exists
-            if os.path.exists(outfn):
-                os.remove(outfn)
-                continue
-            else:
-                os.symlink(inputfn, outfn)
-                if DEBUG:
-                    print("Link %s --> %s" % (inputfn, outfn))
-
-    if len(mic_dict.keys()) == len(done_mics):
+    if len(mic_dict.keys()) == 0:
         print("All mics picked! Nothing to do.")
         open(RELION_JOB_SUCCESS_FILENAME, "w").close()
         exit(0)
@@ -112,12 +111,16 @@ def run_job(project_dir, args):
         '--weights': model,
         '--gpu': "%s" % gpus.replace('"', ''),
         '--threshold': thresh,
-        '-nc': -1 #threads
+        '--distance': distance,
+        '--cleanup': "",
+        '-nc': -1  # threads
     }
     cmd = "%s && %s " % (CONDA_ENV, CRYOLO_PREDICT)
     cmd += " ".join(['%s %s' % (k, v) for k, v in args_dict.items()])
+    cmd += " --input "
     for i in mic_dirs:
-        cmd += " --input %s" % i
+        if len(glob("%s/*%s" % (i, mic_ext))):  # skip folders with no mics
+            cmd += "%s/ " % i
 
     print("Running command:\n{}".format(cmd))
     proc = subprocess.Popen(cmd, shell=True)
@@ -129,15 +132,14 @@ def run_job(project_dir, args):
     # Moving output star files for Relion to use
     with open(DONE_MICS, "a+") as f:
         for mic in mic_dict:
+            f.write("%s\n" % mic)
             mic_base = os.path.basename(mic)
+            os.remove(mic)  # clean up symlink
             coord_cryolo = os.path.splitext(mic_base)[0] + ".star"
             coord_cryolo = getPath(job_dir, "output", "STAR", coord_cryolo)
             coord_relion = mic_dict[mic]
-            # To ensure that cryolo doesn't pick from already done mics
             if os.path.exists(coord_cryolo):
-                f.write("%s\n" % mic)
                 os.rename(coord_cryolo, getPath(job_dir, coord_relion))
-                os.remove(mic)  # clean up
                 if DEBUG:
                     print("Moved %s to %s" % (coord_cryolo, getPath(job_dir, coord_relion)))
 
@@ -197,11 +199,58 @@ def run_job(project_dir, args):
                                      'rlnImageSize'])
         tableCryolo.addRow(diam, boxSize, boxSizeSmall)
         with open(outputFn, "w") as f:
-            tableCryolo.writeStar(f, tableName='cryolo')
+            tableCryolo.writeStar(f, tableName='picker')
+
+        # create .gui_manualpickjob.star for easy display
+        starString = """
+# version 30001
+
+data_job
+
+_rlnJobType                             3
+_rlnJobIsContinue                       0
+
+
+# version 30001
+
+data_joboptions_values
+
+loop_
+_rlnJobOptionVariable #1
+_rlnJobOptionValue #2
+    angpix         -1
+ black_val          0
+blue_value          0
+color_label rlnParticleSelectZScore
+  ctfscale          1
+  diameter         %d
+  do_color         No
+  do_queue         No
+do_startend        No
+  fn_color         ""
+     fn_in         ""
+  highpass         -1
+   lowpass         20
+  micscale        0.2
+min_dedicated       1
+other_args         ""
+      qsub       qsub
+qsubscript /public/EM/RELION/relion/bin/relion_qsub.csh
+ queuename    openmpi
+ red_value          2
+sigma_contrast      3
+ white_val          0
+"""
+        with open(getPath(".gui_manualpickjob.star"), "w") as f:
+            f.write(starString % diam)
+
+    # remove output dir
+    if os.path.isdir("output"):
+        shutil.rmtree("output")
 
     end = time.time()
     diff = end - start
-    print("Job duration = %dh %dmin %dsec \n" % (diff//3600, diff//60%60, diff%60))
+    print("Job duration = %dh %dmin %dsec \n" % (diff//3600, diff//60 % 60, diff % 60))
 
 
 def main():
