@@ -13,14 +13,14 @@ from emtable import Table  # requires pip install emtable
 
 RELION_JOB_FAILURE_FILENAME = "RELION_JOB_EXIT_FAILURE"
 RELION_JOB_SUCCESS_FILENAME = "RELION_JOB_EXIT_SUCCESS"
-CONDA_ENV = ". ~/rc/conda.rc && conda activate cryolo-1.7.5"
+CONDA_ENV = ". /home/gsharov/rc/conda.rc && conda activate cryolo-1.7.5"
 CRYOLO_TRAIN = "cryolo_train.py"
 CRYOLO_GEN_MODEL = "/home/gsharov/soft/cryolo/gmodel_phosnet_202005_N63_c17.h5"
 CRYOLO_JANNI_MODEL = "/home/gsharov/soft/cryolo/gmodel_janni_20190703.h5"
 TUNE_MODEL = "fine_tuned_model.h5"
 IMG_FOLDER = "train_image"
 ANNOT_FOLDER = "train_annot"
-DEBUG = 1
+DEBUG = 0
 
 
 def run_job(project_dir, args):
@@ -114,7 +114,8 @@ def run_job(project_dir, args):
         '--conf': "config.json",
         '--gpu': gpus,
         '--warmup': 0,
-        '--fine_tune': ""
+        '--fine_tune': "",
+        '--cleanup': ""
     }
     cmd = "%s && %s " % (CONDA_ENV, CRYOLO_TRAIN)
     cmd += " ".join(['%s %s' % (k, v) for k, v in args_dict.items()])
@@ -138,7 +139,7 @@ def run_job(project_dir, args):
 
     end = time.time()
     diff = end - start
-    print("Job duration = %dh %dmin %dsec \n" % (diff//3600, diff//60%60, diff%60))
+    print("Job duration = %dh %dmin %dsec \n" % (diff//3600, diff//60 % 60, diff % 60))
 
 
 def main():
