@@ -24,13 +24,12 @@
 # *
 # **************************************************************************
 
-import os
-import subprocess
 # use polling as required for watchdog over NFS/CIFS
 from watchdog.observers.polling import PollingObserver as Observer
 from watchdog.events import RegexMatchingEventHandler
 
 from .config import *
+from .utils.misc import getUsername, setParticleSizes
 from .parser import Parser
 from .schedule import setupRelion, setupScipion
 
@@ -51,9 +50,8 @@ class WatchDog:
                                                   case_sensitive=True)
         event_handler.on_created = self.on_created
 
-        if DEBUG:
-            print("Watchdog started for: %s\n\tregex: %s" %
-                  (path, regex))
+        print("Watchdog started for: %s\n\tregex: %s" %
+              (path, regex))
 
         self.observer.schedule(event_handler, path, recursive=True)
         self.observer.start()
@@ -61,8 +59,7 @@ class WatchDog:
 
     def on_created(self, event):
         mdFn = event.src_path
-        if DEBUG:
-            print("File creation detected: %s" % mdFn)
+        print("File creation detected: %s" % mdFn)
         self.observer.stop()
         start_app(mdFn)
 
@@ -73,15 +70,13 @@ def start_app(mdFn):
         mdPath = "/".join(mdFn.split("/")[:-4])
     else:
         mdPath = "/".join(mdFn.split("/")[:-1])
-    mdFolder = os.path.basename(mdPath)
     model = Parser()
     model.setSoftware(DEF_SOFTWARE)
     model.setPipeline(DEF_PIPELINE)
     model.setMdPath(mdPath)
     model.setFn(mdFn)
 
-    username = mdFolder.split("_")[1]
-    uid = mapUserid(username)
+    username, uid = getUsername(mdPath)
     model.setUser(username, uid)
     model.acqDict['User'] = model.getUser()
 
@@ -91,40 +86,25 @@ def start_app(mdFn):
               model.getMdPath(),
               model.getUser(),
               model.getPipeline())
-        print("\nFiles found: %s\n" % mdFn) if DEBUG else ""
+
+    print("\nFiles found: %s\n" % mdFn)
 
     if DEF_SOFTWARE == 'EPU':
         model.parseImgEpu(mdFn)
     else:  # SerialEM
-        model.parseImgMdoc(mdFn)
+        model.parseImgSem(mdFn)
 
     model.calcDose()
     model.guessDataDir(wait=True)
+    model.acqDict['Picker'] = DEF_PICKER
+    setParticleSizes(model)
 
-    if DEBUG:
-        print("\nFinal parameters:\n")
-        for k, v in sorted(model.acqDict.items()):
-            print(k, v)
-        print('\n')
+    print("\nFinal parameters:\n")
+    for k, v in sorted(model.acqDict.items()):
+        print(k, v)
+    print('\n')
 
     if DEF_PIPELINE == 'Relion':
         setupRelion(model.acqDict)
     else:
         setupScipion(model.acqDict)
-
-
-def mapUserid(login):
-    # find uid from a username using NIS database
-    cmd = "/usr/bin/ypmatch %s passwd" % login
-    try:
-        res = subprocess.check_output(cmd.split())
-    except subprocess.CalledProcessError:
-        print("ERROR: username %s not found! Using default uid: %s" % (
-            login, DEF_USER[1]))
-        return DEF_USER[1]
-    except FileNotFoundError:
-        print("ERROR: command %s not found! Using default uid: %s" % (
-            cmd.split()[0], DEF_USER[1]))
-        return DEF_USER[1]
-    else:
-        return str(res).split(":")[2]
